@@ -1,4 +1,4 @@
-# Copyright 2020 Mechanics of Microstructures Group
+# Copyright 2021 Mechanics of Microstructures Group
 #    at The University of Manchester
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,13 +16,17 @@
 import numpy as np
 import matplotlib as mpl
 import matplotlib.pyplot as plt
+
 from matplotlib.widgets import Button, TextBox
+from matplotlib.collections import LineCollection
 from matplotlib_scalebar.scalebar import ScaleBar
 from mpl_toolkits.mplot3d.art3d import Poly3DCollection
 from mpl_toolkits.mplot3d import Axes3D
+from matplotlib.ticker import FuncFormatter
 
 from skimage import morphology as mph
 
+from defdap import defaults
 from defdap import quat
 # TODO: add plot parameter to add to current figure
 
@@ -31,7 +35,7 @@ class Plot(object):
     """ Class used for creating and manipulating plots.
 
     """
-    def __init__(self, ax, axParams={}, fig=None, makeInteractive=False,
+    def __init__(self, ax=None, axParams={}, fig=None, makeInteractive=False,
                  title=None, **kwargs):
         self.interactive = makeInteractive
         if makeInteractive:
@@ -45,6 +49,8 @@ class Plot(object):
             self.btnStore = []
             self.txtStore = []
             self.txtBoxStore = []
+            self.p1=[];self.p2=[];
+
         else:
             self.fig = fig
             # TODO: flag for new figure
@@ -54,6 +60,7 @@ class Plot(object):
             else:
                 self.ax = ax
         self.colourBar = None
+        self.arrow = None
 
         if title is not None:
             self.setTitle(title)
@@ -117,7 +124,7 @@ class Plot(object):
 
         self.btnStore.append(btn)
 
-    def addTextBox(self, label, submitHandler, loc=(0.8, 0.0, 0.1, 0.07), **kwargs):
+    def addTextBox(self, label, submitHandler=None, changeHandler=None, loc=(0.8, 0.0, 0.1, 0.07), **kwargs):
         """Add a text box to the plot.
 
         Parameters
@@ -139,7 +146,10 @@ class Plot(object):
         self.checkInteractive()
         txtBoxAx = self.fig.add_axes(loc)
         txtBox = TextBox(txtBoxAx, label, **kwargs)
-        txtBox.on_submit(lambda e: submitHandler(e, self))
+        if submitHandler != None:
+            txtBox.on_submit(lambda e: submitHandler(e, self))
+        if changeHandler != None:    
+            txtBox.on_text_change(lambda e: changeHandler(e, self))
 
         self.txtBoxStore.append(txtBox)
 
@@ -166,6 +176,48 @@ class Plot(object):
         txt = ax.text(x, y, txt, **kwargs)
         self.txtStore.append(txt)
 
+    def addArrow(self, startEnd, persistent=False, clearPrev=True, label=None):
+        """Add arrow to grain plot.
+
+        Parameters
+        ----------
+        startEnd: 4-tuple
+            Starting (x, y), Ending (x, y).
+        persistent :
+            If persistent, do not clear arrow with clearPrev.
+        clearPrev :
+            Clear all non-persistent arrows.
+        label
+            Label to place near arrow.
+
+        """
+
+        arrowParams = {
+            'xy': startEnd[0:2],        # Arrow start coordinates
+            'xycoords': 'data',
+            'xytext': startEnd[2:4],    # Arrow end coordinates
+            'textcoords': 'data',
+            'arrowprops': dict(arrowstyle="<-", connectionstyle="arc3",
+                               color='red', alpha=0.7, linewidth=2,
+                               shrinkA=0, shrinkB=0)
+        }
+
+        # If persisent, add the arrow onto the plot directly
+        if persistent:
+            self.ax.annotate("", **arrowParams)
+
+        # If not persistent, save a reference so that it can be removed later
+        if not persistent:
+            if clearPrev and (self.arrow is not None): self.arrow.remove()
+            if None not in startEnd:
+                self.arrow = self.ax.annotate("", **arrowParams)
+
+        # Add a label if specified
+        if label is not None:
+            self.ax.annotate(label, xy=startEnd[2:4], xycoords='data',
+                             xytext=(15, 15), textcoords='offset pixels',
+                             c='red', fontsize=14, fontweight='bold')
+
     def setSize(self, size):
         """Set size of plot.
 
@@ -188,6 +240,38 @@ class Plot(object):
         """
         self.fig.canvas.set_window_title(txt)
 
+    def lineSlice(self, event, plot, action=None):
+        """ Catch click and drag then draw an arrow.
+
+        Parameters
+        ----------
+        event :
+            Click event.
+        plot : defdap.plotting.Plot
+            Plot to capture clicks from.
+        action
+            Further action to perform.
+
+        Examples
+        ----------
+        To use, add a click and release event handler to your plot, pointing to this function:
+
+        >>> plot.addEventHandler('button_press_event',lambda e, p: lineSlice(e, p))
+        >>> plot.addEventHandler('button_release_event', lambda e, p: lineSlice(e, p))
+
+        """
+
+        if event.inaxes is self.ax:
+            if event.name == 'button_press_event':
+                self.p1 = (event.xdata, event.ydata)  # save 1st point
+            elif event.name == 'button_release_event':
+                self.p2 = (event.xdata, event.ydata)  # save 2nd point
+                self.addArrow(startEnd=(self.p1[0], self.p1[1], self.p2[0], self.p2[1]))
+                self.fig.canvas.draw_idle()
+
+                if action is not None:
+                    action(plot=self, startEnd=(self.p1[0], self.p1[1], self.p2[0], self.p2[1]))
+
     @property
     def exists(self):
         self.checkInteractive()
@@ -306,44 +390,73 @@ class MapPlot(Plot):
             scale = self.callingMap.scale * 1e-6
         self.ax.add_artist(ScaleBar(scale))
 
-    def addGrainBoundaries(self, colour=None, dilate=False):
+    def addGrainBoundaries(self, kind="pixel", boundaries=None, colour=None, 
+                           dilate=False, draw=True, **kwargs):
         """Add grain boundaries to the plot.
 
         Parameters
         ----------
+        kind : str, {"pixel", "line"}
+            Type of boundaries to plot, either a boundary image or a
+            collection of line segments.
+        boundaries : various, optional
+            Boundaries to plot, either a boundary image or a list of pairs
+            of coordinates representing the start and end of each boundary 
+            segment. If not provided the boundaries are loaded from the 
+            calling map.
         colour : str
             Colour of grain boundaries.
         dilate : bool
-            If true, dilate the grain boundaries
+            If true, dilate the grain boundaries.
+        kind
 
         Returns
         -------
-        matplotlib.image.AxesImage
+        Various :
+            matplotlib.image.AxesImage if type is pixel
 
         """
         if colour is None:
             colour = "white"
 
-        boundariesImage = -self.callingMap.boundaries
+        if kind == "line":
+            boundaryLines = boundaries
+            if boundaryLines is None:
+                boundaryLines = self.callingMap.boundaryLines
 
-        if dilate:
-            boundariesImage = mph.binary_dilation(boundariesImage)
+            lc = LineCollection(boundaryLines,
+                                colors=mpl.colors.to_rgba(colour), **kwargs)
 
-        # create colourmap for boundaries going from transparent to
-        # opaque of the given colour
-        boundariesCmap = mpl.colors.LinearSegmentedColormap.from_list(
-            'my_cmap', ['white', colour], 256
-        )
-        boundariesCmap._init()
-        boundariesCmap._lut[:, -1] = np.linspace(0, 1, boundariesCmap.N + 3)
+            self.ax.add_collection(lc)
+            # ax.autoscale()
 
-        img = self.ax.imshow(boundariesImage, cmap=boundariesCmap,
-                             interpolation='None', vmin=0, vmax=1)
-        self.draw()
+            if draw:
+                self.draw()
+        else:
+            boundariesImage = boundaries
+            if boundariesImage is None:
+                boundariesImage = self.callingMap.boundaries
+            boundariesImage = -boundariesImage
 
-        self.imgLayers.append(img)
+            if dilate:
+                boundariesImage = mph.binary_dilation(boundariesImage)
 
-        return img
+            # create colourmap for boundaries going from transparent to
+            # opaque of the given colour
+            boundariesCmap = mpl.colors.LinearSegmentedColormap.from_list(
+                'my_cmap', ['white', colour], 256
+            )
+            boundariesCmap._init()
+            boundariesCmap._lut[:, -1] = np.linspace(0, 1, boundariesCmap.N + 3)
+
+            img = self.ax.imshow(boundariesImage, cmap=boundariesCmap,
+                                 interpolation='None', vmin=0, vmax=1)
+            if draw:
+                self.draw()
+
+            self.imgLayers.append(img)
+
+            return img
 
     def addGrainHighlights(self, grainIds, grainColours=None, alpha=None,
                            newLayer=False):
@@ -370,10 +483,7 @@ class MapPlot(Plot):
         if alpha is None:
             alpha = self.callingMap.highlightAlpha
 
-        xDim = self.callingMap.xDim
-        yDim = self.callingMap.yDim
-
-        outline = np.zeros((yDim, xDim), dtype=int)
+        outline = np.zeros(self.callingMap.shape, dtype=int)
         for i, grainId in enumerate(grainIds, start=1):
             if i > len(grainColours):
                 i = len(grainColours)
@@ -499,7 +609,7 @@ class MapPlot(Plot):
 
         Parameters
         ----------
-        callingMap : Map
+        callingMap : base.Map
             DIC or EBSD map which called this plot.
         mapData : numpy.ndarray
             Data to be plotted.
@@ -560,7 +670,9 @@ class MapPlot(Plot):
             plot.addColourBar(clabel)
 
         if plotGBs:
-            plot.addGrainBoundaries(colour=boundaryColour, dilate=dilateBoundaries)
+            plot.addGrainBoundaries(
+                colour=boundaryColour, dilate=dilateBoundaries, kind=plotGBs
+            )
 
         if highlightGrains is not None:
             plot.addGrainHighlights(
@@ -573,34 +685,6 @@ class MapPlot(Plot):
 
         return plot
 
-
-class LineSlice:
-    """ Class to catch click and drag and return start and end positions.
-
-    """
-    def __init__(self, fig, ax, action):
-        self.p1=[0,0]
-        self.p2=[0,0]
-        self.ax = ax
-        self.cidclick = plt.connect('button_press_event', self)
-        self.cidrelease = plt.connect('button_release_event', self)
-        self.action = action
-        self.fig=fig
-
-    def __call__(self, event):
-        if event.name == 'button_press_event':
-            self.p1 = (event.xdata, event.ydata)    # save 1st point
-        elif event.name == 'button_release_event':
-            self.p2 = (event.xdata, event.ydata)    # save 2nd point
-
-            self.action(startEnd=(self.p1[0], self.p1[1], self.p2[0], self.p2[1]))
-            self.fig.canvas.draw()
-
-            self.points = (self.p1[0], self.p1[1], self.p2[0], self.p2[1])
-
-            return self.p1[0], self.p1[1], self.p2[0], self.p2[1]
-
-
 class GrainPlot(Plot):
     """ Class for creating a map for a grain.
 
@@ -642,62 +726,12 @@ class GrainPlot(Plot):
         img = self.ax.imshow(mapData, vmin=vmin, vmax=vmax,
                              interpolation='None', cmap=cmap, **kwargs)
         self.draw()
-        self.arrow = None
 
         self.imgLayers.append(img)
 
         return img
 
-    def addArrow(self, startEnd, persistent=False, clearPrev=True, label=None):
-        """Add arrow to grain plot.
 
-        Parameters
-        ----------
-        startEnd: 4-tuple
-            Starting (x, y), Ending (x, y).
-        persistent :
-            If persistent, do not clear arrow with clearPrev.
-        clearPrev :
-            Clear all non-persistent arrows.
-        label
-            Label to place near arrow.
-
-        """
-
-        x0 = startEnd[0]
-        y0 = startEnd[1]
-        x1 = startEnd[2]
-        y1 = startEnd[3]
-
-        if persistent:
-            self.ax.annotate(
-                "", xy=(x0, y0), xycoords='data', xytext=(x1, y1),
-                textcoords='data', arrowprops=dict(
-                    arrowstyle="<-", connectionstyle="arc3",
-                    color='red', alpha=0.7, linewidth=2
-                )
-            )
-
-        if not persistent:
-            if clearPrev:
-                if self.arrow is not None:
-                    self.arrow.remove()
-
-            if None in (x0, y0, x1, y1):
-                pass
-            else:
-                self.arrow = self.ax.annotate(
-                    "", xy=(x0, y0), xycoords='data', xytext=(x1, y1),
-                    textcoords='data', arrowprops=dict(
-                        arrowstyle="<-", connectionstyle="arc3",
-                        color='red',alpha=0.7,linewidth=2
-                    )
-                )
-
-        if label is not None:
-            self.ax.annotate(label, xy=(x1, y1), xycoords='data',
-                             xytext=(15, 15), textcoords='offset pixels',
-                             c='red', fontsize=12)
 
     def addColourBar(self, label, layer=0, **kwargs):
         """Add colour bar to grain plot.
@@ -753,7 +787,7 @@ class GrainPlot(Plot):
         # When plotting top half only, move all 'traces' to +ve y
         # and set the pivot to be in the tail instead of centre
         if topOnly:
-            pivot='tail'
+            pivot = 'tail'
             for idx, (x,y) in enumerate(zip(traces[0], traces[1])):
                 if x < 0 and y < 0:
                     traces[0][idx] *= -1
@@ -843,7 +877,7 @@ class GrainPlot(Plot):
 
         Parameters
         ----------
-        callingGrain : Grain
+        callingGrain : base.Grain
             DIC or EBSD grain which called this plot.
         mapData :
             Data to be plotted.
@@ -909,8 +943,6 @@ class PolePlot(Plot):
     """ Class for creating an inverse pole figure plot.
 
     """
-    defaultProjection = "stereographic"
-
     def __init__(self, plotType, crystalSym, projection=None,
                  fig=None, ax=None, axParams={}, makeInteractive=False,
                  **kwargs):
@@ -973,7 +1005,7 @@ class PolePlot(Plot):
                             padY=0.009, va='bottom', ha='center', fontsize=12)
 
         else:
-            raise NotImplementedError("Only works for cubic and hexagonal IPFs")
+            raise NotImplementedError("Only works for cubic and hexagonal.")
 
         self.ax.axis('equal')
         self.ax.axis('off')
@@ -1033,7 +1065,7 @@ class PolePlot(Plot):
         padY : int, optional
             Pad added to y coordinate.
         kwargs
-            Other arguments will be passed to :func:`matplotlib.axes.Axes.text`.
+            Other arguments are passed to :func:`matplotlib.axes.Axes.text`.
 
         """
         xp, yp = self.projection(*point)
@@ -1054,7 +1086,7 @@ class PolePlot(Plot):
         markerSize : float
             Size of marker.
         kwargs
-            Other arguments will be passed to :func:`matplotlib.axes.Axes.scatter`.
+            Other arguments are passed to :func:`matplotlib.axes.Axes.scatter`.
 
         Raises
         -------
@@ -1101,7 +1133,7 @@ class PolePlot(Plot):
             raise Exception("specify one colour for solid markers or list two for 'half and half'")
 
     def addColourBar(self, label, layer=0, **kwargs):
-        """Add colourbar to pole plot.
+        """Add a colour bar to the pole plot.
 
         Parameters
         ----------
@@ -1110,11 +1142,32 @@ class PolePlot(Plot):
         layer : int
             Layer number to add the colour bar to.
         kwargs
-            Other argument will be passed to :func:`matplotlib.pyplot.colorbar`.
+            Other argument are passed to :func:`matplotlib.pyplot.colorbar`.
 
         """
         img = self.imgLayers[layer]
         self.colourBar = plt.colorbar(img, ax=self.ax, label=label, **kwargs)
+        
+    def addLegend(self, label='Grain area (μm$^2$)', number=6, layer=0, scaling=1, **kwargs):
+        """Add a marker size legend to the pole plot.
+
+        Parameters
+        ----------
+        label : str
+            Label to place next to legend.
+        number :
+            Number of markers to plot in legend.
+        layer : int
+            Layer number to add the colour bar to.
+        scaling : float
+            Scaling applied to the data.
+        kwargs
+            Other argument are passed to :func:`matplotlib.pyplot.legend`.
+
+        """
+        img = self.imgLayers[layer]
+        self.legend = plt.legend(*img.legend_elements("sizes", num=number,
+                            func=lambda s: s / scaling), title=label, **kwargs)
 
     @staticmethod
     def _validateProjection(projectionIn, validateDefault=False):
@@ -1122,7 +1175,7 @@ class PolePlot(Plot):
             defaultProjection = None
         else:
             defaultProjection = PolePlot._validateProjection(
-                PolePlot.defaultProjection, validateDefault=True
+                defaults['pole_projection'], validateDefault=True
             )
 
         if projectionIn is None:
@@ -1146,7 +1199,7 @@ class PolePlot(Plot):
             projection = defaultProjection
 
         if projection is None:
-            raise Exception("Problem with default projection.")
+            raise ValueError("Problem with default projection.")
 
         return projection
 
@@ -1221,16 +1274,18 @@ class HistPlot(Plot):
     """ Class for creating a histogram.
 
     """
-    def __init__(self, plotType="linear", density=True, fig=None,
+    def __init__(self, plotType = "scatter", axesType="linear", density=True, fig=None,
                  ax=None, axParams={}, makeInteractive=False, **kwargs):
         """Initialise a histogram plot
 
         Parameters
         ----------
-        plotType : str, {'log', 'None'}, optional
-            If 'log' is specified, logarithmic y scale will be used.
+        plotType: str, {'scatter', 'bar', 'step'}
+            Type of plot to use
+        axesType : str, {'linear', 'logx', 'logy', 'loglog', 'None'}, optional
+            If 'log' is specified, logarithmic scale is used.
         density :
-            If true, histogram will be normalised such that the integral sums to 1.
+            If true, histogram is normalised such that the integral sums to 1.
         fig : matplotlib.figure.Figure
             Matplotlib figure to plot on.
         ax : matplotlib.axes.Axes
@@ -1240,7 +1295,7 @@ class HistPlot(Plot):
         makeInteractive : bool
             If true, make the plot interactive.
         kwargs
-            Other arguments will be passed to :class:`defdap.plotting.Plot`
+            Other arguments are passed to :class:`defdap.plotting.Plot`
 
         """
         super(HistPlot, self).__init__(
@@ -1248,21 +1303,32 @@ class HistPlot(Plot):
             **kwargs
         )
 
-        plotType = plotType.lower()
-        if plotType in ["linear", "log"]:
-            self.plotType = plotType
+        axesType = axesType.lower()
+        if axesType in ["linear", "logy", "logx", "loglog"]:
+            self.axesType = axesType
         else:
             raise ValueError("plotType must be linear or log.")
 
+        if plotType in ['scatter', 'bar', 'step']:
+            self.plotType = plotType
+        else:
+            raise ValueError("plotType must be scatter, bar or step.")
+
         self.density = bool(density)
 
         # set y-axis label
         yLabel = "Normalised frequency" if self.density else "Frequency"
-        if self.plotType == "log":
-            yLabel = "ln({})".format(yLabel)
         self.ax.set_ylabel(yLabel)
 
-    def addHist(self, histData, bins=10, range=None, line='o',
+        # set axes to linear or log as appropriate and set to be numbers as opposed to scientific notation
+        if self.axesType == 'logx' or self.axesType == 'loglog':
+            self.ax.set_xscale("log")
+            self.ax.xaxis.set_major_formatter(FuncFormatter(lambda y, _: '{:.5g}'.format(y)))
+        if self.axesType == 'logy' or self.axesType == 'loglog':
+            self.ax.set_yscale("log")
+            self.ax.yaxis.set_major_formatter(FuncFormatter(lambda y, _: '{:.5g}'.format(y)))
+
+    def addHist(self, histData, bins=100, range=None, line='o',
                 label=None, **kwargs):
         """Add a histogram to the current plot
 
@@ -1277,21 +1343,31 @@ class HistPlot(Plot):
         line : str, optional
             Marker or line type to be used.
         label : str, optional
-            Label to use for data (will be used for legend).
+            Label to use for data (used for legend).
         kwargs
-            Other arguments will be passed to :func:`numpy.histogram`
+            Other arguments are passed to :func:`numpy.histogram`
 
         """
 
-        hist = np.histogram(histData.flatten(), bins=bins, range=range,
-                            density=self.density)
+        # Generate the x bins with appropriate spaceing for linear or log
+        if self.axesType == 'logx' or self.axesType == 'loglog':
+            binList = np.logspace(np.log10(range[0]), np.log10(range[1]), bins)
+        else:
+            binList = np.linspace(range[0], range[1], bins)
 
-        yVals = hist[0]
-        if self.plotType == "log":
-            yVals = np.log(yVals)
-        xVals = 0.5 * (hist[1][1:] + hist[1][:-1])
 
-        self.ax.plot(xVals, yVals, line, label=label, **kwargs)
+        if self.plotType == 'scatter':
+            # Generate the histogram data and plot as a scatter plot
+            hist = np.histogram(histData.flatten(), bins=binList, density=self.density)
+            yVals = hist[0]
+            xVals = 0.5 * (hist[1][1:] + hist[1][:-1])
+
+            self.ax.plot(xVals, yVals, line, label=label, **kwargs)
+
+        else:
+            # Plot as a matplotlib histogram
+            self.ax.hist(histData.flatten(),bins=binList, histtype=self.plotType,
+                         density=self.density, label=label, **kwargs)
 
     def addLegend(self, **kwargs):
         """Add legend to histogram.
@@ -1308,7 +1384,7 @@ class HistPlot(Plot):
     def create(
         cls, histData, fig=None, figParams={}, ax=None, axParams={},
         plot=None, makeInteractive=False,
-        plotType="linear", density=True, bins=10, range=None,
+        plotType = "scatter", axesType="linear", density=True, bins=10, range=None,
         line='o', label=None, **kwargs
     ):
         """Create a histogram plot.
@@ -1326,13 +1402,15 @@ class HistPlot(Plot):
         axParams :
             Passed to defdap.plotting.Plot as axParams.
         plot : defdap.plotting.HistPlot
-            Plot where histgram will be places. If none, placed on current active plot.
+            Plot where histgram is created. If none, a new plot is created.
         makeInteractive : bool, optional
             If true, make plot interactive.
-        plotType : str, {'log', 'None'}, optional
-            If 'log' is specified, logarithmic y scale will be used.
+        plotType: str, {'scatter', 'bar', 'barfilled', 'step'}
+            Type of plot to use
+        axesType : str, {'linear', 'logx', 'logy', 'loglog', 'None'}, optional
+            If 'log' is specified, logarithmic scale is used.
         density :
-            If true, histogram will be normalised such that the integral sums to 1.
+            If true, histogram is normalised such that the integral sums to 1.
         bins : int
             Number of bins to use for histogram.
         range : tuple or None, optional
@@ -1340,9 +1418,9 @@ class HistPlot(Plot):
         line : str, optional
             Marker or line type to be used.
         label : str, optional
-            Label to use for data (will be used for legend).
+            Label to use for data (is used for legend).
         kwargs
-            Other arguments will be passed to :func:`defdap.plotting.HistPlot.addHist`
+            Other arguments are passed to :func:`defdap.plotting.HistPlot.addHist`
 
         Returns
         -------
@@ -1350,7 +1428,7 @@ class HistPlot(Plot):
 
         """
         if plot is None:
-            plot = cls(plotType=plotType, density=density, fig=fig, ax=ax,
+            plot = cls(axesType=axesType, plotType=plotType, density=density, fig=fig, ax=ax,
                        axParams=axParams, makeInteractive=makeInteractive,
                        **figParams)
         plot.addHist(histData, bins=bins, range=range, line=line,
@@ -1378,7 +1456,7 @@ class CrystalPlot(Plot):
         makeInteractive : bool, optional
             If true, make plot interactive.
         kwargs
-            All other arguments are passed to :class:`defdap.plotting.Plot`.
+            Other arguments are passed to :class:`defdap.plotting.Plot`.
 
         """
         # Set default plot parameters then update with input
@@ -1398,13 +1476,6 @@ class CrystalPlot(Plot):
             **figParams
         )
 
-        # Set plotting parameters
-        self.ax.set_xlim3d(-0.15, 0.15)
-        self.ax.set_ylim3d(-0.15, 0.15)
-        self.ax.set_zlim3d(-0.15, 0.15)
-        self.ax.view_init(azim=270, elev=90)
-        self.ax._axis3don = False
-
     def addVerts(self, verts, **kwargs):
         """Plots planes, defined by the vertices provided.
 
@@ -1413,15 +1484,15 @@ class CrystalPlot(Plot):
         verts : list
             List of vertices.
         kwargs
-            All other arguments are passed to :class:`matplotlib.collections.PolyCollection`.
+            Other arguments are passed to :class:`matplotlib.collections.PolyCollection`.
 
         """
         # Set default plot parameters then update with any input
         plotParams = {
-            'alpha' : 0.6,
-            'facecolor' : '0.8',
-            'linewidths' : 3,
-            'edgecolor' : 'k'
+            'alpha': 0.6,
+            'facecolor': '0.8',
+            'linewidths': 3,
+            'edgecolor': 'k'
         }
         plotParams.update(kwargs)
 
